@@ -74,7 +74,7 @@ class FreqDict(models.Model):
             lem = Lemma.objects.filter(pk=int(wfs[key]['IdLemma']))
             if len(lem) != 1:
                 continue
-            wfss.append(WordForm(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq']))
+            wfss.append(WordForm(pk=int(key),Lemma = lem[0],Frequency = int(wfs[key]['Freq'])))
         WordForm.objects.bulk_create(wfss)
         for w in wfss:
             #ts = [Transcription(Transcription=t
